@@ -112,11 +112,15 @@ def max_sim(model, document_vec, concept_vec):
     comparisons = 0
     start_time = time.time()
     for term_1 in document_vec:
-        max_similarity = 0.0
+        max_similarity = -1
         matched_term = None
         for term_2 in concept_vec:
             comparisons += 1
             current_similarity = model.similarity(term_1, term_2)
+            if current_similarity < -1:
+                current_similarity =-1
+            if current_similarity >1 :
+                current_similarity=1
             if current_similarity > max_similarity:
                 max_similarity = current_similarity
                 matched_term = term_2
@@ -172,7 +176,7 @@ def initialize_model(path_corpus,path_model,path_model_vocab,n):
             top_n_preprocessed[concept]={}
             for term in preprocessed[concept]:
                 if term in top_n_terms:
-                    top_n_preprocessed[term]=preprocessed[concept][term]
+                    top_n_preprocessed[concept][term]=preprocessed[concept][term]
         top_n_tf = compute_tf(top_n_preprocessed, concepts, top_n_bows, top_n_terms)
         top_n_tfidf=compute_tfidf(top_n_tf,idfs,top_n_terms)
         esa_matrix = get_esa_matrix(top_n, top_n_tfidf, concepts)
